@@ -6,21 +6,24 @@ import os
 import re
 import sys
 import shutil
+import inspect
 import zipfile
 import tempfile
 import unittest
 import textwrap
 import contextlib
-from inspect import getsourcefile
 
 try:
     from StringIO import StringIO
 except ImportError:
     from io import StringIO  # For python3.
 
-from whereis import resolve, locate, LocateError, main, __doc__ as usage_string
+from whereis import (resolve, locate, LocateError, main,
+                     __doc__ as usage_string, _normalize_path)
 
 
+PY3_3 = (3, 3)
+
 def write_to_file(filepath, data=''):
     """Create the file in ``path`` and write ``data`` in it."""
     if isinstance(filepath, (tuple, list)):
@@ -28,6 +31,12 @@ def write_to_file(filepath, data=''):
     with open(filepath, 'w') as file_:
         file_.write(data)
 
+
+def getsourcefile(obj):
+    """Fix of ``inspect.getsourcefile`` that return absolute path."""
+    return _normalize_path(inspect.getsourcefile(obj))
+
+
 @contextlib.contextmanager
 def capture_output(stdout=True, stderr=False):
     """Context manager for capturing stdout, stderr in ``StringIO`` instance
@@ -77,7 +86,7 @@ class PyWhereisTestCase(unittest.TestCase):
     """TestCase class for the functions locate, resolve, main."""
 
     def test_builtin_packages(self):
-        """Test built-in resolving module and package."""
+        """Test not pure python resolving module and package."""
         self.assertEqual(resolve('sys'), sys)
         self.assertEqual(resolve('os'), os)
         self.assertEqual(resolve('os.path'), os.path)
@@ -130,7 +139,9 @@ class PyWhereisTestCase(unittest.TestCase):
             self.assertEqual(resolve('a.b.e.FooBar.Bar.baz').__name__, 'baz')
 
             # locate should find module/package even if the import will fail.
-            self.assertEqual(locate('a.b.d'), os.path.join(tmpdir, 'a/b/d.py'))
+            self.assertEqual(
+                locate('a.b.d'),
+                _normalize_path(os.path.join(tmpdir, 'a/b/d.py')))
             # The path returned should always be absolute.
             filepath = locate('a.b.e.FooBar.Bar.baz').split()[0]
             if not os.path.isabs(filepath):
@@ -142,7 +153,7 @@ class PyWhereisTestCase(unittest.TestCase):
         """Test broken module/package resolve."""
         tmpdir = tempfile.mkdtemp()
         # The module a.py will raise a SyntaxError when imported/executed.
-        module_path = os.path.join(tmpdir, 'a.py')
+        module_path = os.path.realpath(os.path.join(tmpdir, 'a.py'))
         write_to_file(module_path, 'raise SyntaxError')
 
         try:
@@ -169,7 +180,8 @@ class PyWhereisTestCase(unittest.TestCase):
             main(['os'])
 
         stdlib_os_path = output[0].read()
-        self.assertEqual(stdlib_os_path, 'os: %s\n' % getsourcefile(os))
+        os_path = _normalize_path(getsourcefile(os))
+        self.assertEqual(stdlib_os_path, 'os: %s\n' % os_path)
 
         tmpdir = tempfile.mkdtemp()
         # Save the current directory to be able to go back to it.
@@ -178,12 +190,15 @@ class PyWhereisTestCase(unittest.TestCase):
         # to check the -s/--site-packages option .
         os.chdir(tmpdir)
         # Create a new os module in the temporary directory.
-        new_os_path = os.path.join(tmpdir, 'os.py')
+        new_os_path = os.path.realpath(os.path.join(tmpdir, 'os.py'))
         write_to_file(new_os_path)
         try:
             with capture_output() as output:
                 main(['os'])
-            self.assertEqual(output[0].read(), 'os: %s\n' % new_os_path)
+            if sys.version_info < PY3_3:
+                self.assertEqual(output[0].read(), 'os: %s\n' % new_os_path)
+            else:
+                self.assertEqual(output[0].read(), stdlib_os_path)
 
             # When using the -s option the return value should be stdlib os.
             with capture_output() as output:
@@ -203,7 +218,7 @@ class PyWhereisTestCase(unittest.TestCase):
         # Test the verbose argument.
         with capture_output() as output:
             main(['-v', 'sys'])
-        self.assertEqual(output[0].read(),'sys: Error: %r is built-in.\n' % sys)
+        self.assertEqual(output[0].read(),'sys: Error: %r is not pure python.\n' % sys)
 
         # Call main (script) with no dotted_name.
         with capture_output(stderr=True) as output:
@@ -243,7 +258,7 @@ class PyWhereisTestCase(unittest.TestCase):
         # Locate to tmpdir to be able to add foo.py without all parent dirs.
         os.chdir(tmpdir)
         # Create a zip archive and add the python module to it.
-        zip_filepath = os.path.join(tmpdir, 'a.zip')
+        zip_filepath = _normalize_path(os.path.join(tmpdir, 'a.zip'))
         zip_fp = zipfile.ZipFile(zip_filepath, 'w')
         zip_fp.write(test_module)
         zip_fp.close()
@@ -252,7 +267,8 @@ class PyWhereisTestCase(unittest.TestCase):
 
         try:
             # Add the zip to sys.path be be able to importe module inside it.
-            module_fullpath = os.path.join(zip_filepath, test_module)
+            module_fullpath = _normalize_path(
+                os.path.join(zip_filepath, test_module))
             sys.path.insert(0, zip_filepath)
             self.assertEqual(locate('foo'), module_fullpath)
             self.assertEqual(locate('foo.bar'), '%s 1' % module_fullpath)
